@@ -2,18 +2,18 @@
 # https://raw.githubusercontent.com/paul-buerkner/brms/refs/heads/master/R/posterior.R
 
 #'
-#' Transform \code{blrmfit} to \code{draws} objects
+#' Transform \code{blrmfit} or \code{blrm_trial} to \code{draws} objects
 #'
 #' @description
 #' `r lifecycle::badge("experimental")`
 #' 
-#' Transform a \code{blrmfit} object to a format supported by the
+#' Transform a \code{blrmfit} or \code{blrm_trial} object to a format supported by the
 #' \pkg{posterior} package.
 #'
 #' @aliases as_draws as_draws_matrix as_draws_array as_draws_df
 #' @aliases as_draws_rvars as_draws_list
 #'
-#' @param x A \code{blrmfit} object.
+#' @param x A \code{blrmfit} or \code{blrm_trial} object.
 #' @param variable A character vector providing the variables to
 #'   extract.  By default, all variables are extracted.
 #' @param regex Logical; Should variable be treated as a (vector of)
@@ -26,7 +26,7 @@
 #'
 #' @details To subset iterations, chains, or draws, use the
 #'   \code{\link[posterior:subset_draws]{subset_draws}} method after
-#'   transforming the \code{blrmfit} to a \code{draws} object.
+#'   transforming the input object to a \code{draws} object.
 #'
 #' The function is experimental as the set of exported posterior
 #' variables are subject to updates.
@@ -54,10 +54,9 @@ NULL
 as_draws.blrmfit <- function(x, variable = NULL, regex = FALSE,
                              inc_warmup = FALSE, ...) {
   # draws_list is the fastest format to convert to at the moment
-  as_draws_list(
-    x, variable = variable, regex = regex,
-    inc_warmup = inc_warmup, ...
-  )
+  .as_draws_conversion(x$stanfit,
+                       as_draws_list, variable = variable,
+                       regex = regex, inc_warmup = inc_warmup, ...)
 }
 
 #' @rdname draws-OncoBayes2
@@ -67,10 +66,9 @@ as_draws.blrmfit <- function(x, variable = NULL, regex = FALSE,
 #' @export as_draws_matrix
 as_draws_matrix.blrmfit <- function(x, variable = NULL, regex = FALSE,
                                     inc_warmup = FALSE, ...) {
-  as_draws_matrix(as_draws_list(
-    x, variable = variable, regex = regex,
-    inc_warmup = inc_warmup, ...
-  ))
+  .as_draws_conversion(x$stanfit,
+                       as_draws_matrix, variable = variable,
+                       regex = regex, inc_warmup = inc_warmup, ...)
 }
 
 #' @rdname draws-OncoBayes2
@@ -80,10 +78,9 @@ as_draws_matrix.blrmfit <- function(x, variable = NULL, regex = FALSE,
 #' @export as_draws_array
 as_draws_array.blrmfit <- function(x, variable = NULL, regex = FALSE,
                                    inc_warmup = FALSE, ...) {
-  as_draws_array(as_draws_list(
-    x, variable = variable, regex = regex,
-    inc_warmup = inc_warmup, ...
-  ))
+  .as_draws_conversion(x$stanfit,
+                       as_draws_array, variable = variable,
+                       regex = regex, inc_warmup = inc_warmup, ...)
 }
 
 #' @rdname draws-OncoBayes2
@@ -93,10 +90,9 @@ as_draws_array.blrmfit <- function(x, variable = NULL, regex = FALSE,
 #' @export as_draws_df
 as_draws_df.blrmfit <- function(x, variable = NULL, regex = FALSE,
                                 inc_warmup = FALSE, ...) {
-  as_draws_df(as_draws_list(
-    x, variable = variable, regex = regex,
-    inc_warmup = inc_warmup, ...
-  ))
+  .as_draws_conversion(x$stanfit,
+                       as_draws_df, variable = variable,
+                       regex = regex, inc_warmup = inc_warmup, ...)
 }
 
 #' @rdname draws-OncoBayes2
@@ -106,10 +102,9 @@ as_draws_df.blrmfit <- function(x, variable = NULL, regex = FALSE,
 #' @export as_draws_list
 as_draws_list.blrmfit <- function(x, variable = NULL, regex = FALSE,
                                   inc_warmup = FALSE, ...) {
-  .as_draws_list(
-    x$stanfit, variable = variable, regex = regex,
-    inc_warmup = inc_warmup, ...
-  )
+  .as_draws_conversion(x$stanfit,
+                       as_draws_list, variable = variable,
+                       regex = regex, inc_warmup = inc_warmup, ...)
 }
 
 #' @rdname draws-OncoBayes2
@@ -119,24 +114,23 @@ as_draws_list.blrmfit <- function(x, variable = NULL, regex = FALSE,
 #' @export as_draws_rvars
 as_draws_rvars.blrmfit <- function(x, variable = NULL, regex = FALSE,
                                    inc_warmup = FALSE, ...) {
-  as_draws_rvars(as_draws_list(
-    x, variable = variable, regex = regex,
-    inc_warmup = inc_warmup, ...
-  ))
+  .as_draws_conversion(x$stanfit,
+                       as_draws_rvars, variable = variable,
+                       regex = regex, inc_warmup = inc_warmup, ...)
 }
 
 # in stanfit objects draws are stored in a draws_list-like format
 # so converting from there will be most efficient
 # may be removed once rstan supports posterior natively
 #' @keywords internal
-.as_draws_list <- function(x, variable = NULL, regex = FALSE,
-                           inc_warmup = FALSE, ...) {
+.as_draws_conversion <- function(x, draws_converter, variable = NULL, regex = FALSE,
+                                 inc_warmup = FALSE, ...) {
   stopifnot(.is.stanfit(x))
   inc_warmup <- .as_one_logical(inc_warmup)
   if (!length(x@sim$samples)) {
     .stop2("The model does not contain posterior draws.")
   }
-  out <- as_draws_list(x)
+  out <- draws_converter(x)
   # first subset variables then remove warmup as removing warmup
   # will take a lot of time when extracting many variables
   out <- subset_draws(out, variable = variable, regex = regex)
@@ -192,3 +186,76 @@ as_draws_rvars.blrmfit <- function(x, variable = NULL, regex = FALSE,
   }
   out
 }
+
+#' @rdname draws-OncoBayes2
+#' @importFrom posterior as_draws
+#' @method as_draws blrm_trial
+#' @export
+#' @export as_draws
+as_draws.blrm_trial <- function(x, variable = NULL, regex = FALSE,
+                                inc_warmup = FALSE, ...) {
+  .assert_is_blrm_trial_and_prior_is_set(x)
+  as_draws(x$blrmfit, variable = variable,
+           regex = regex, inc_warmup = inc_warmup, ...)
+}
+
+#' @rdname draws-OncoBayes2
+#' @importFrom posterior as_draws_matrix
+#' @method as_draws_matrix blrm_trial
+#' @export
+#' @export as_draws_matrix
+as_draws_matrix.blrm_trial <- function(x, variable = NULL, regex = FALSE,
+                                    inc_warmup = FALSE, ...) {
+  .assert_is_blrm_trial_and_prior_is_set(x)
+  as_draws_matrix(x$blrmfit, variable = variable,
+                  regex = regex, inc_warmup = inc_warmup, ...)
+}
+
+#' @rdname draws-OncoBayes2
+#' @importFrom posterior as_draws_array
+#' @method as_draws_array blrm_trial
+#' @export
+#' @export as_draws_array
+as_draws_array.blrm_trial <- function(x, variable = NULL, regex = FALSE,
+                                   inc_warmup = FALSE, ...) {
+  .assert_is_blrm_trial_and_prior_is_set(x)
+  as_draws_array(x$blrmfit, variable = variable,
+                 regex = regex, inc_warmup = inc_warmup, ...)
+}
+
+#' @rdname draws-OncoBayes2
+#' @importFrom posterior as_draws_df
+#' @method as_draws_df blrm_trial
+#' @export
+#' @export as_draws_df
+as_draws_df.blrm_trial <- function(x, variable = NULL, regex = FALSE,
+                                inc_warmup = FALSE, ...) {
+  .assert_is_blrm_trial_and_prior_is_set(x)
+  as_draws_df(x$blrmfit, variable = variable,
+              regex = regex, inc_warmup = inc_warmup, ...)
+}
+
+#' @rdname draws-OncoBayes2
+#' @importFrom posterior as_draws_list
+#' @method as_draws_list blrm_trial
+#' @export
+#' @export as_draws_list
+as_draws_list.blrm_trial <- function(x, variable = NULL, regex = FALSE,
+                                  inc_warmup = FALSE, ...) {
+  .assert_is_blrm_trial_and_prior_is_set(x)
+  as_draws_list(x$blrmfit, variable = variable,
+           regex = regex, inc_warmup = inc_warmup, ...)
+}
+
+#' @rdname draws-OncoBayes2
+#' @importFrom posterior as_draws_rvars
+#' @method as_draws_rvars blrm_trial
+#' @export
+#' @export as_draws_rvars
+as_draws_rvars.blrm_trial <- function(x, variable = NULL, regex = FALSE,
+                                   inc_warmup = FALSE, ...) {
+  .assert_is_blrm_trial_and_prior_is_set(x)
+  as_draws_rvars(x$blrmfit, variable = variable,
+           regex = regex, inc_warmup = inc_warmup, ...)
+}
+
